==> codelite_6.1.1+dfsg.orig.tar.gz: codelite-6.1.1/LiteEditor/colourrequest.h <==
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////
//
// copyright            : (C) 2008 by Eran Ifrah                            
// file name            : colourrequest.h              
//                                                                          
// -------------------------------------------------------------------------
// A                                                                        
//              _____           _      _     _ _                            
//             /  __ \         | |    | |   (_) |                           
//             | /  \/ ___   __| | ___| |    _| |_ ___                      
//             | |    / _ \ / _  |/ _ \ |   | | __/ _ )                     
//             | \__/\ (_) | (_| |  __/ |___| | ||  __/                     
//              \____/\___/ \__,_|\___\_____/_|\__\___|                     
//                                                                          
//                                                  F i l e                 
//                                                                          
//    This program is free software; you can redistribute it and/or modify  
//    it under the terms of the GNU General Public License as published by  
//    the Free Software Foundation; either version 2 of the License, or     
//    (at your option) any later version.                                   
//                                                                          
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////
 #ifndef __colourrequest__
#define __colourrequest__
#include "wx/filename.h"
#include "worker_thread.h"

class ColourRequest : public ThreadRequest
{

	wxFileName m_fileToColour;

public:
	ColourRequest();
	~ColourRequest();

	void SetFileToColour(const wxFileName& fileToColour) ;
	const wxFileName& GetFileToColour() const ;
};
#endif // __colourrequest__

==> codelite_18.2.0.orig.tar.gz: codelite-18.2.0/LiteEditor/colourrequest.h <==
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////
//
// copyright            : (C) 2008 by Eran Ifrah                            
// file name            : colourrequest.h              
//                                                                          
// -------------------------------------------------------------------------
// A                                                                        
//              _____           _      _     _ _                            
//             /  __ \         | |    | |   (_) |                           
//             | /  \/ ___   __| | ___| |    _| |_ ___                      
//             | |    / _ \ / _  |/ _ \ |   | | __/ _ )                     
//             | \__/\ (_) | (_| |  __/ |___| | ||  __/                     
//              \____/\___/ \__,_|\___\_____/_|\__\___|                     
//                                                                          
//                                                  F i l e                 
//                                                                          
//    This program is free software; you can redistribute it and/or modify  
//    it under the terms of the GNU General Public License as published by  
//    the Free Software Foundation; either version 2 of the License, or     
//    (at your option) any later version.                                   
//                                                                          
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////
 #ifndef __colourrequest__
#define __colourrequest__

#include "worker_thread.h"

#include <wx/filename.h>

class ColourRequest : public ThreadRequest
{

	wxFileName m_fileToColour;

public:
	ColourRequest() = default;
	~ColourRequest() = default;

	void SetFileToColour(const wxFileName& fileToColour) ;
	const wxFileName& GetFileToColour() const ;
};
#endif // __colourrequest__
